==> inico-1.0.0.tgz: package/src/index.ts <==
import * as nubes from "nubes-collections"

/**
 * The Key of INI
 * 
 * @export
 * @class Key
 * @extends {(nubes.KeyValue<string, string | number>)}
 */
export class Key extends nubes.KeyValue<string, string | number>{

    /**
     * Creates an instance of Key.
     * 
     * @param {string} key
     * @param {(string | number)} value
     */
    constructor(key: string, value: string | number) {
        super(key, value);
    }
}

/**
 * The list of Keys
 * 
 * @export
 * @class KeyList
 * @extends {nubes.List<Key>}
 */
export class KeyList extends nubes.List<Key>{

    /**
     * Use the Key's name to get the key.
     * 
     * @param {string} key The key of the key-value
     * @returns {Key}
     */
    getByName(key: string): Key {
        for (let index = 0; index < this.count; index++) {
            let element = this.get(index);
            if (element.key == key) {
                return element;
            }
        }
    }
}

/**
 * The Section of the INI
 * 
 * @export
 * @class Section
 */
export class Section {

    /**
     * The name of the Section
     * 
     * @private
     * @type {string}
     */
    public name: string;

    /**
     * The Section's list of keys.
     * 
     * @type {KeyList}
     */
    public keys: KeyList = new KeyList();

    /**
     * Creates an instance of Section.
     * 
     * @param {string} name The section's name
     */
    constructor(name: string) {
        this.name = name;
    }

}

/**
 * The list of sections
 * 
 * @export
 * @class SectionList
 * @extends {nubes.List<Section>}
 */
export class SectionList extends nubes.List<Section>{
    /**
     * Use the name to get the section
     * 
     * @param {string} name The name of section
     * @returns {Section}
     */
    getByName(name: string): Section {
        for (let index = 0; index < this.count; index++) {
            let element = this.get(index);
            if (element.name == name) {
                return element;
            }
        }
    }
}

/**
 * The INI class
 * 
 * @export
 * @class INI
 */
export class INI {
    /**
     * The section checking regex
     * 
     * @private
     * @static
     */
    private static _sectionRegex = /\[(.*)\]/;

    /**
     * The section list of INI
     * 
     * @type {SectionList}
     */
    public sections: SectionList = new SectionList();

    /**
     * Convert string content to INI object
     * 
     * @static
     * @param {string} content
     * @returns {INI}
     */
    static convertToINI(content: string): INI {
        let result: INI = new INI();
        let currentSectionCounter: number = -1;
        let stringList = content.split('\n');
        for (let statement of stringList) {

            // Section check
            if (this._sectionRegex.test(statement) == true) {
                let regexResult = this._sectionRegex.exec(statement);
                result.sections.add(new Section(regexResult[1]));
                currentSectionCounter += 1;
            }
            // Comment check
            else if (statement[0] == '#' || statement[0] == ';' || statement[0] == '\n' || statement[0] == '\r\n' || statement[0] == '\r') {
                continue;
            }
            // Key check
            else {
                let key: string = "";
                let value: string = "";
                let swticher: boolean = false;
                for (let char of statement) {
                    if (char == '=' && swticher == false){
                        swticher = true;
                        continue;
                    }
                    if (char == '#' || char == ';'){
                        break;
                    }
                    if (swticher == false) {
                        key += char;
                        continue;
                    }
                    else {
                        value += char;
                        continue;
                    }
                }
                result.sections.get(currentSectionCounter).keys.add(new Key(key,value.trim()));
            }
        }
        return result;
    }

    /**
     * Convert INI object to string
     * 
     * @static
     * @param {INI} ini
     * @returns {string}
     */
    static convertToString(ini: INI): string {
        let result: string = "";
        for (let i = 0; i < ini.sections.count; i++) {
            let tmpSection = ini.sections.get(i);
            result += `[${tmpSection.name}]\n`;
            for (var j = 0; j < tmpSection.keys.count; j++) {
                let tmpKey = tmpSection.keys.get(j);
                result += `${tmpKey.key} = ${tmpKey.value.toString()}\n`
            }
        }
        return result;
    }
}

==> inico-1.0.1.tgz: package/src/index.ts <==
import * as nubes from "nubes-collections"

/**
 * The Key of INI
 * 
 * @export
 * @class Key
 * @extends {(nubes.KeyValue<string, string | number>)}
 */
export class Key extends nubes.KeyValuePair<string, string | number>{

    /**
     * Creates an instance of Key.
     * 
     * @param {string} key
     * @param {(string | number)} value
     */
    constructor(key: string, value: string | number) {
        super(key, value);
    }
}

/**
 * The list of Keys
 * 
 * @export
 * @class KeyList
 * @extends {nubes.List<Key>}
 */
export class KeyList extends nubes.List<Key>{

    /**
     * Use the Key's name to get the key.
     * 
     * @param {string} key The key of the key-value
     * @returns {Key}
     */
    getByName(key: string): Key {
        for (let index = 0; index < this.count; index++) {
            let element = this.get(index);
            if (element.key == key) {
                return element;
            }
        }
    }
}

/**
 * The Section of the INI
 * 
 * @export
 * @class Section
 */
export class Section {

    /**
     * The name of the Section
     * 
     * @private
     * @type {string}
     */
    public name: string;

    /**
     * The Section's list of keys.
     * 
     * @type {KeyList}
     */
    public keys: KeyList = new KeyList();

    /**
     * Creates an instance of Section.
     * 
     * @param {string} name The section's name
     */
    constructor(name: string) {
        this.name = name;
    }

}

/**
 * The list of sections
 * 
 * @export
 * @class SectionList
 * @extends {nubes.List<Section>}
 */
export class SectionList extends nubes.List<Section>{
    /**
     * Use the name to get the section
     * 
     * @param {string} name The name of section
     * @returns {Section}
     */
    getByName(name: string): Section {
        for (let index = 0; index < this.count; index++) {
            let element = this.get(index);
            if (element.name == name) {
                return element;
            }
        }
    }
}

/**
 * The INI class
 * 
 * @export
 * @class INI
 */
export class INI {
    /**
     * The section checking regex
     * 
     * @private
     * @static
     */
    private static _sectionRegex = /\[(.*)\]/;

    /**
     * The section list of INI
     * 
     * @type {SectionList}
     */
    public sections: SectionList = new SectionList();

    /**
     * Convert string content to INI object
     * 
     * @static
     * @param {string} content
     * @returns {INI}
     */
    static convertToINI(content: string): INI {
        let result: INI = new INI();
        let currentSectionCounter: number = -1;
        let stringList = content.split('\n');
        for (let statement of stringList) {

            // Section check
            if (this._sectionRegex.test(statement) == true) {
                let regexResult = this._sectionRegex.exec(statement);
                result.sections.add(new Section(regexResult[1]));
                currentSectionCounter += 1;
            }
            // Comment check
            else if (statement[0] == '#' || statement[0] == ';' || statement[0] == '\n' || statement[0] == '\r\n' || statement[0] == '\r') {
                continue;
            }
            // Key check
            else {
                let key: string = "";
                let value: string = "";
                let swticher: boolean = false;
                for (let char of statement) {
                    if (char == '=' && swticher == false){
                        swticher = true;
                        continue;
                    }
                    if (char == '#' || char == ';'){
                        break;
                    }
                    if (swticher == false) {
                        key += char;
                        continue;
                    }
                    else {
                        value += char;
                        continue;
                    }
                }
                result.sections.get(currentSectionCounter).keys.add(new Key(key,value.trim()));
            }
        }
        return result;
    }

    /**
     * Convert INI object to string
     * 
     * @static
     * @param {INI} ini
     * @returns {string}
     */
    static convertToString(ini: INI): string {
        let result: string = "";
        for (let i = 0; i < ini.sections.count; i++) {
            let tmpSection = ini.sections.get(i);
            result += `[${tmpSection.name}]\n`;
            for (var j = 0; j < tmpSection.keys.count; j++) {
                let tmpKey = tmpSection.keys.get(j);
                result += `${tmpKey.key} = ${tmpKey.value.toString()}\n`
            }
        }
        return result;
    }
}
